import React, { useEffect, useState } from 'react'
import { Spin, Card, Form, Select, Input, Button, notification } from 'antd'
import Wangedit from '@/components/Wangedit/Wangedit';
import ImageUpload from '@/components/XForm/ImageUpload'
import { fetch, apis } from '@/utils/request';

const FormItem = Form.Item
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 3 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 19 },
  },
}

const editorMenus = [
  'head', // 标题
  'bold', // 粗体
  'italic', // 斜体
  'underline', // 下划线
  'strikeThrough', // 删除线
  'indent', // 缩进
  'lineHeight', // 行高
  'foreColor', // 文字颜色
  'list', // 列表
  'justify', // 对齐方式
  'quote', // 引用
  'undo', // 撤销
];

const getAgentRule = fetch(apis.broker.getAgentRule)
const saveAgentRule = fetch(apis.broker.saveAgentRule)

const AgentRule = React.forwardRef((props, ref) => {
  const { getFieldDecorator, validateFieldsAndScroll, setFieldsValue } = props.form

  const [loading, setLoading] = useState(false)
  const [detail, setDetail] = useState({})

  const handleSubmit = (e) => {
    validateFieldsAndScroll((err, values) => {
      if (err) return;

      setLoading(true)
      saveAgentRule({ data: { ...(detail || {}), ...values, referralFee: (values.referralFee || 0) * 100 } }).then(res => {
        // setDetail(res)
        setLoading(false)
        notification.success({ message: "操作成功" })
      }).catch(() => {
        setLoading(false)
      })
    })

    return false;
  }

  useEffect(() => {
    setLoading(true)
    getAgentRule().then(res => {
      const formData = {
        ...(res || {}),
        referralFee: ((res || {}).referralFee || 0) / 100,
      }

      // ant3 的 form 赋值很诡异
      const t = setTimeout(() => {
        clearTimeout(t)
        setLoading(false)
        setDetail(formData)
        setFieldsValue(formData)
      }, 200)
    }).catch(() => {
      setLoading(false)
    })
  }, [])

  return (
    <Card>
      <Spin spinning={loading}>
        <Form {...formItemLayout} onSubmit={handleSubmit}>
          <FormItem label="海报背景" help="建议图片尺寸：640*960px，比例2:3,格式：jpg">
            {
              getFieldDecorator('poster', {
                rules: [{ required: true, message: '请上传海报背景' }],
              })(<ImageUpload />)
            }
          </FormItem>
          <FormItem label="推荐金额" help="推荐经纪人奖励">
            {
              getFieldDecorator('referralFee')(
                <Input
                  defaultValue={0.00}
                  min={0.00}
                  step={0.01}
                  style={{ width: '100%' }}
                  type="number"
                  addonBefore="￥"
                  addonAfter="元"
                />
              )
            }
          </FormItem>
          <FormItem label="规则详情">
            { 
              getFieldDecorator('content')(<Wangedit menus={editorMenus} />)
            }
          </FormItem>
          <FormItem label="发布状态">
            { 
              getFieldDecorator('status')(
                <Select>
                  <Select.Option value={1}>发布</Select.Option>
                  <Select.Option value={0}>未发布</Select.Option>
                </Select>
              )
            }
          </FormItem>
          <FormItem colon={false} label=" ">
            <Button type="primary" htmlType="submit" loading={loading}>
              提交
            </Button>
          </FormItem>
        </Form>
      </Spin>
    </Card>
  )
})

export default Form.create()(AgentRule)
