import React, { useEffect, useState } from 'react'
import { Spin, Card, Form, Select, Input, Button, notification } from 'antd'
import SelectCity from '@/components/SelectButton/CitySelect'
import ImageUpload from '@/components/XForm/ImageUpload'
import Wangedit from '@/components/Wangedit/Wangedit';
import { fetch, apis } from '@/utils/request';
import { router } from 'umi';
import { formItemLayout, showTypeList, pages } from '../util'

const FormItem = Form.Item
const Option = Select.Option

const editorMenus = [
  'head', // 标题
  'bold', // 粗体
  'italic', // 斜体
  'underline', // 下划线
  'strikeThrough', // 删除线
  'indent', // 缩进
  'lineHeight', // 行高
  'foreColor', // 文字颜色
  'list', // 列表
  'justify', // 对齐方式
  'quote', // 引用
  'undo', // 撤销
];
const fullWidth = { width: '100%' }

const getFirstScreenDetail = fetch(apis.broker.getFirstScreenDetail)
const saveFirstScreen = fetch(apis.broker.saveFirstScreen)
const updateFirstScreen = fetch(apis.broker.updateFirstScreen)

const AnnouncementEdit = React.forwardRef((props, ref) => {
  const { history, form } = props
  const { query } = history.location
  const { id } = query
  const { getFieldDecorator, validateFieldsAndScroll, setFieldsValue } = form

  const [loading, setLoading] = useState(false)

  const handlePageChange = (path) => {
    const page = pages.filter(x => x.page === path)[0]
    if (page) {
      setFieldsValue({ pageParam: page.queryStr })
    }
  }

  const handleSubmit = (e) => {
    validateFieldsAndScroll((err, values) => {
      if (err) return;

      setLoading(true)
      const p = !id ? saveFirstScreen({ data: values }) : updateFirstScreen({ urlData: { id }, data: values })
      p.then(res => {
        // setFieldsValue(res)
        setLoading(false)
        notification.success({ message: "操作成功" })
        router.goBack()
      }).catch(() => {
        setLoading(false)
      })
    })
  }

  useEffect(() => {
    if (id) {
      setLoading(true)
      getFirstScreenDetail({ urlData: { id } }).then(res => {
        // ant3 的 form 赋值很诡异
        const t = setTimeout(() => {
          clearTimeout(t)
          setLoading(false)
          setFieldsValue(res)
        }, 200)
      }).catch(() => {
        setLoading(false)
      })
    } else {
      setFieldsValue({
        showType: 'first-screen'
      })
    }
  }, [id, setFieldsValue])

  return (
    <Card>
      <Spin spinning={loading}>
        <Form {...formItemLayout} onSubmit={handleSubmit}>
          <FormItem label="公告类型">
            {
              getFieldDecorator('showType', {
                rules: [{ required: true, message: '请填写标题' }],
              })(
                <Select style={fullWidth} allowClear>
                  {
                    showTypeList.map(x => <Option key={x.value} value={x.value}>{x.label}</Option>)
                  }
                </Select>
              )
            }
          </FormItem>
          <FormItem label="公告图片" help="建议图片尺寸：640*960px，比例2:3,格式：jpg">
            {
              getFieldDecorator('imageUrl', {
                rules: [{ required: true, message: '公告图片' }],
              })(<ImageUpload />)
            }
          </FormItem>
          <FormItem label="公告标题">
            {
              getFieldDecorator('title', {
                rules: [{ required: true, message: '请填写标题' }],
              })(<Input />)
            }
          </FormItem>
          <FormItem label="所属城市">
            {
              getFieldDecorator('cityId', {
                rules: [{ required: true, message: '请选择城市' }],
              })(
                <SelectCity style={fullWidth} />,
              )
            }
          </FormItem>
          <FormItem label="跳转页面">
            {
              getFieldDecorator('linkPage')(
                <Select style={fullWidth} allowClear onChange={handlePageChange}>
                  {
                    pages.map(x => <Option key={x.page} value={x.page}>{x.title}</Option>)
                  }
                </Select>
              )
            }
          </FormItem>
          <FormItem label="页面参数" help="默认不需要处理">
            {
              getFieldDecorator('pageParam')(<Input placeholder="key1=value1&key2=value2" />)
            }
          </FormItem>
          <FormItem label="公告详情">
            { 
              getFieldDecorator('content')(<Wangedit menus={editorMenus} />)
            }
          </FormItem>
          <FormItem colon={false} label=" ">
            <Button type="primary" htmlType="submit" loading={loading}>
              提交
            </Button>
            <Button onClick={router.goBack} style={{ marginLeft: '2em' }}>
              返回
            </Button>
          </FormItem>
        </Form>
      </Spin>
    </Card>
  )
})

export default Form.create()(AnnouncementEdit)
