import React, { useMemo, useRef, useCallback, useState } from 'react'
import { Button, notification, Spin, Badge } from 'antd'
import { router } from 'umi'
import moment from 'moment'
import QueryTable from '@/components/QueryTable'
import SelectCity from '@/components/SelectButton/CitySelect'
import OperButton from '@/components/OperButton'
import { fetch, apis } from '@/utils/request';

import { pages } from './util'

const searchFields = [
  {
    name: 'cityId',
    label: '城市',
    placeholder: '请选择城市',
    render: () => <SelectCity style={{width: 160}} />
  },
]

const updateFirstScreen = fetch(apis.broker.updateFirstScreen)

const actionRender = () => {
  const gotoAdd = () => router.push('/broker/announcement/edit')
  return (
    <Button type="primary" icon="plus" onClick={gotoAdd}>新增</Button>
  )
}

export default (props) => {
  const ref = useRef()
  const [loading, setLoading] = useState(false)
  const [page, setPage] = useState({current: 1, pageSize: 10})
    
  const tableColumns = [
    {
      title: '图片',
      dataIndex: 'imageUrl',
      key: 'imageUrl',
      align: 'center',
      render: (t) => {
        return <img src={t} width={64} height={96} style={{borderRadius: '4px'}} alt="" />
      }
    },
    {
      title: '标题',
      dataIndex: 'title',
      key: 'title',
      render: (t, row) => <Button type="link" onClick={() => router.push(`/broker/announcement/edit?id=${row.screenId}`)}>{t}</Button>
    },
    {
      title: '跳转页面',
      dataIndex: 'linkPage',
      key: 'linkPage',
      render: t => (pages.filter(x => x.page === t)[0] || {}).title
    },
    {
      title: '时间',
      dataIndex: 'createDate',
      key: 'createDate',
      align: 'center',
      render: (t) => moment(t).format('YYYY-MM-DD HH:mm')
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      align: 'center',
      render: (t) => t === 1 ? <Badge status="success" text="已发布" /> : <Badge status="processing" text="未发布" />
    },
    {
      title: '操作',
      key: 'options',
      align: 'center',
      render: (_, row) => (
        <>
          <OperButton onClick={() => router.push(`/broker/announcement/edit?id=${row.screenId}`)}>详情</OperButton>
          <OperButton.Confirm title="确认进行操作?" color="#1890ff" onClick={() => onPublish(row)}>{row.status === 1 ? '取消发布' : '发布'}</OperButton.Confirm>
        </>
      )
    },
  ]

  const onPublish = (row) => {
    setLoading(true)
    updateFirstScreen({ urlData: { id: row.screenId }, data: { status: Math.abs(row.status - 1) } }).then(() => {
      setLoading(false)

      // 修改记录
      ref.current.refreshList((list, next) => {
        next(list.map(it => {
          if (it.screenId === row.screenId) {
            return {
              ...it,
              status: Math.abs(row.status - 1)
            }
          } else {
            return it
          }
        }))
      })
    }).catch(() => {
      setLoading(false)
    })
  }

  return (
    <Spin spinning={loading}>
      <QueryTable
        ref={ref}
        rowKey="screenId"
        api={apis.broker.getFirstScreenList}
        searchFields={searchFields}
        columns={tableColumns}
        actionRender={actionRender}
        onPageChange={(pg) => setPage(pg)}
      />
    </Spin>
  )
}
