
import React, { useEffect, useRef, useState } from 'react'
import { Button, Spin, Radio, Form, Input, Row, Col, notification } from 'antd'
import { fetch, apis } from '@/utils/request';
import Wangedit from '@/components/Wangedit/Wangedit';
import { formItemLayout } from '../utils'

const FormItem = Form.Item
const updateBroker = fetch(apis.broker.updateBuildingBroker)
const getAgreementList = fetch(apis.broker.getBkAgreementList)
const saveAgreement = fetch(apis.broker.saveBkAgreement)

const editorMenus = [
  'head', // 标题
  'bold', // 粗体
  'italic', // 斜体
  'underline', // 下划线
  'strikeThrough', // 删除线
  'indent', // 缩进
  'lineHeight', // 行高
  'foreColor', // 文字颜色
  'list', // 列表
  'justify', // 对齐方式
  'quote', // 引用
  'undo', // 撤销
];

const Broker = React.forwardRef((props, ref) => {
  const { form, buildingInfo = {} } = props
  const buildingId = buildingInfo.buildingId

  const [loading, setLoading] = useState(false)
  const [isBroker, setIsBroker] = useState('false')
  const [bkAgreement, setBkAgreement] = useState()

  const canEdit = isBroker === 'true'

  const handleBrokerChange = (e) => {
    const { value } = e.target
    setLoading(true)
    updateBroker({ urlData: { id: buildingId }, params: { on: value } }).then(() => {
      setLoading(false)
      setIsBroker(value)
    }).catch(() => {
      setLoading(false)
    })
  }

  const handelSubmit = () => {
    form.validateFieldsAndScroll((err, values) => {
      if (err) return;

      const data = {
        ...values || {},
        buildingId,
        buildingName: buildingInfo.name,
        cityId: buildingInfo.cityId,
      }

      setLoading(true)
      saveAgreement({ data }).then(res => {
        setLoading(false)
        // setBkAgreement(res)
        form.setFieldsValue(res || {});
        notification.success({ message: "操作成功" })
      }).catch((err) => {
        setLoading(false)
      })
    })
  }

  useEffect(() => {
    if (buildingId) {
      setLoading(true)
      getAgreementList({ params: { buildingId } }).then(res => {
        setLoading(false)
        const { records = [] } = res
        // setBkAgreement(records[0])
        form.setFieldsValue(records[0] || {});
      }).catch(() => {
        setLoading(false)
      })

      setIsBroker(buildingInfo.isBroker ? 'true' : 'false')
    }
  }, [buildingId])

  return (
    <Spin spinning={loading}>
      <div style={{ padding: '1.2em', paddingTop: 0 }}>
        <Row type="flex" align="middle">
          <Col span={2}>
            <div style={{ textAlign: 'right', marginRight: '1em' }}>全民经纪人</div>
          </Col>
          <Col span={12}>
            <Radio.Group value={isBroker} onChange={handleBrokerChange} buttonStyle="solid">
              <Radio.Button value="true">开启</Radio.Button>
              <Radio.Button value="false">关闭</Radio.Button>
            </Radio.Group>
          </Col>
        </Row>
      </div>
      <div style={{ maxWidth: canEdit ? '100%' : '0', maxHeight: canEdit ? '100%' : '0',  overflow: 'hidden' }}>
        <Form {...formItemLayout} onSubmit={handelSubmit} >
          <FormItem label="有效期">
            {form.getFieldDecorator('expirationDays', {
              rules: [{ required: true, message: '请填写有效期' }],
            })(<Input suffix="天" />)}          
          </FormItem>
          <FormItem label="佣金规则">
            {form.getFieldDecorator('content', {
              rules: [{ required: true, message: '请填写佣金规则' }],
            })(<Wangedit menus={editorMenus} />)}          
          </FormItem>
          <FormItem colon={false} label=" ">
            <Button type="primary" htmlType="submit" loading={loading}>
              提交
            </Button>
          </FormItem>
        </Form>
      </div>
    </Spin>
  )
})

export default Form.create()(Broker)
